@@ -142,8 +142,9 @@ fitme <- function(formula,data, ## matches minimal call of HLfit
   #
   if ( ! is.null(weights.form)) {
     mc[["prior.weights"]] <-  weights.form[[2]]
-  } else if ("prior.weights" %in%  evalq(names(substitute(...())))) { # ~ R >= 4.1's ...names() 
+  #} else if ("prior.weights" %in%  evalq(names(substitute(...())))) { # ~ R >= 4.1's ...names() 
                                                                       # substitute(...())  trick found in a Dunlap post to R-devel, 22/05/2020, 20:53
+  } else if ("prior.weights" %in%  ...names()) { 
     p_weights <- substitute(alist(...))$prior.weights # necessary when prior weights has been passed to fitme 
     # through the '...' of another function. In that case we reconstruct the call argument as if they had not been passed in this way.
     # is user quoted the pw, the str() of the result of the substitute() calls is language quote(...)  ~  doubly quoted stuff... => eval 
